@@ -289,7 +289,8 @@ def readWig_with_fixedStep_variableStep_writeChrBasedSignalArrays(outputDir, job
             print('before outlier removal number of rows: %d' % (wigfile_interval_version_df.shape[0]))
             file_df = wigfile_interval_version_df[wigfile_interval_version_df[SIGNAL] < q]
             print('after outlier removal number of rows: %d' % (file_df.shape[0]))
-        # Outlier elimination ends
+        else:
+            file_df = wigfile_interval_version_df
 
         file_df_grouped = file_df.groupby(CHROM)
         pool = multiprocessing.Pool(numofProcesses)
@@ -297,18 +298,19 @@ def readWig_with_fixedStep_variableStep_writeChrBasedSignalArrays(outputDir, job
         poolInputList = []
 
         for chrLong, chromBasedFileDF in file_df_grouped:
-            chromSize = chromSizesDict[chrLong]
-            inputList = []
-            inputList.append(outputDir)
-            inputList.append(jobname)
-            inputList.append(chrLong)
-            inputList.append(chromSize)
-            inputList.append(chromBasedFileDF)
-            inputList.append(wig_file_path)
-            inputList.append(occupancy_type)
-            inputList.append(max_signal)
-            inputList.append(min_signal)
-            poolInputList.append(inputList)
+            if chrLong in chromSizesDict:
+                chromSize = chromSizesDict[chrLong]
+                inputList = []
+                inputList.append(outputDir)
+                inputList.append(jobname)
+                inputList.append(chrLong)
+                inputList.append(chromSize)
+                inputList.append(chromBasedFileDF)
+                inputList.append(wig_file_path)
+                inputList.append(occupancy_type)
+                inputList.append(max_signal)
+                inputList.append(min_signal)
+                poolInputList.append(inputList)
 
         pool.map(writeChrBasedOccupancySignalArray, poolInputList)
 
@@ -747,18 +749,19 @@ def readBEDandWriteChromBasedSignalArrays(outputDir, jobname, genome,BEDFileWith
             poolInputList = []
 
             for chrLong, chromBasedFileDF in file_df_grouped:
-                chromSize = chromSizesDict[chrLong]
-                inputList = []
-                inputList.append(outputDir)
-                inputList.append(jobname)
-                inputList.append(chrLong)
-                inputList.append(chromSize)
-                inputList.append(chromBasedFileDF)
-                inputList.append(BEDFileWithPath)
-                inputList.append(occupancy_type)
-                inputList.append(max_signal)
-                inputList.append(min_signal)
-                poolInputList.append(inputList)
+                if chrLong in chromSizesDict:
+                    chromSize = chromSizesDict[chrLong]
+                    inputList = []
+                    inputList.append(outputDir)
+                    inputList.append(jobname)
+                    inputList.append(chrLong)
+                    inputList.append(chromSize)
+                    inputList.append(chromBasedFileDF)
+                    inputList.append(BEDFileWithPath)
+                    inputList.append(occupancy_type)
+                    inputList.append(max_signal)
+                    inputList.append(min_signal)
+                    poolInputList.append(inputList)
 
             pool.map(writeChrBasedOccupancySignalArray, poolInputList)
 
@@ -775,6 +778,7 @@ def readBEDandWriteChromBasedSignalArrays(outputDir, jobname, genome,BEDFileWith
 #Read all data at once, filter w.r.t. a quantileValue and write chrom based in parallel
 #This function is used for GM12878 and K562 nucleosome occupancy chrom based signal npy files creation in parallel
 #For in house use, also has sequential write version
+#quantileValue set as 0.97 For  GM12878 and K562 MNase-seq data
 def readAllNucleosomeOccupancyDataAndWriteChrBasedSignalCountArraysInParallel(genome, quantileValue, nucleosomeFilename):
     chromSizesDict = getChromSizesDict(genome)
 
