@@ -35,7 +35,6 @@ from matplotlib.colors import Normalize
 
 from SigProfilerTopography.source.commons.TopographyCommons import DATA
 from SigProfilerTopography.source.commons.TopographyCommons import FIGURE
-from SigProfilerTopography.source.commons.TopographyCommons import ALL
 from SigProfilerTopography.source.commons.TopographyCommons import PROCESSIVITY
 from SigProfilerTopography.source.commons.TopographyCommons import USING_ONE_SAMPLE_TTEST
 from SigProfilerTopography.source.commons.TopographyCommons import USING_NULL_DISTRIBUTION
@@ -97,10 +96,10 @@ def plot_color_bar(outputDir,jobname,norm):
 
     ##################################################################################
     #create the directory if it does not exists
-    os.makedirs(os.path.join(outputDir, jobname, FIGURE, ALL, PROCESSIVITY), exist_ok=True)
+    os.makedirs(os.path.join(outputDir, jobname, FIGURE, PROCESSIVITY), exist_ok=True)
     filename = '%s_Processivity_ColorBar.png' %(jobname)
 
-    figFile = os.path.join(outputDir, jobname, FIGURE, ALL, PROCESSIVITY, filename)
+    figFile = os.path.join(outputDir, jobname, FIGURE, PROCESSIVITY, filename)
     fig.savefig(figFile)
     plt.cla()
     plt.close(fig)
@@ -202,7 +201,12 @@ def plotRelationshipBetweenSignaturesandProcessiveGroupLengthsUsingDataframes(ou
 
                 if expectedValues and (len(expectedValues) > 0) and (np.any(expectedValues)):
                     # zstat, pvalue = ztest(expectedValues, value=observedValue) results in very small p-values therefore we are not calling in this way.
-                    zstat, pvalue = ztest(expectedValues, [observedValue])
+                    try:
+                        # zstat, pvalue = ztest(expectedValues, [observedValue])
+                        #alternative hypothesis: difference between mean of expected values and mean of observed values is less than zero.
+                        zstat, pvalue = ztest(expectedValues, [observedValue],alternative = 'smaller')
+                    except FloatingPointError:
+                        print('FloatingPointError zstat, pvalue = ztest(%s, [%d])' % (expectedValues, observedValue))
                     # if pvalue is None or np.nan qvalue can not be calculated.
                     if (pvalue is not None) and (not np.isnan(pvalue)):
                         all_p_values.append(pvalue)
@@ -254,10 +258,10 @@ def plotRelationshipBetweenSignaturesandProcessiveGroupLengthsUsingDataframes(ou
         rejected, all_FDR_BH_adjusted_p_values, alphacSidak, alphacBonf = statsmodels.stats.multitest.multipletests(all_p_values_array, alpha=0.05, method='fdr_bh', is_sorted=False, returnsorted=False)
     except ZeroDivisionError:
         print('ZeroDivisionError during statsmodels.stats.multitest.multipletests')
-        print('for debug ZeroDivisionError, all_p_values_array:')
-        print(all_p_values_array)
+        print('all_p_values_array: %s' %(all_p_values_array))
     ##########################################################################################
 
+
     if all_FDR_BH_adjusted_p_values is not None:
         minus_log10_all_FDR_BH_adjusted_p_values = [-math.log10(q_value) if (q_value > 0 and q_value < SIGNIFICANCE_LEVEL) else np.nan for q_value in all_FDR_BH_adjusted_p_values]
     else:
@@ -307,15 +311,63 @@ def plotRelationshipBetweenSignaturesandProcessiveGroupLengthsUsingDataframes(ou
     ############################# Calculate q-values ends ############################
     ####################################################################################
 
+
     ###################################################################
     ############### For information starts ############################
     ###################################################################
     # Get the highest processive group length with a nonzero radius
     #'Signature', 'Processsive_Group_Length', 'Number_of_Processive_Groups', 'Radius'
-    maxProcessiveGroupLength= max(signature_radius_df[(signature_radius_df['Radius']>0)]['Processsive_Group_Length'].values)
 
-    if verbose: print('\tVerbose Processivity plot will be for this maxProcessiveGroupLength:%d' % (maxProcessiveGroupLength))
-    if verbose: print('\tVerbose len(sortedProcessiveGroupLengthList):%d' % (len(sorted_processsive_group_length_list)))
+    processive_group_length_nparray = signature_radius_df[(signature_radius_df['Radius'] > 0)]['Processsive_Group_Length'].values
+
+    if (processive_group_length_nparray.size>0):
+        maxProcessiveGroupLength= max(processive_group_length_nparray)
+        if verbose: print('\tVerbose Processivity plot will be for this maxProcessiveGroupLength:%d' % (maxProcessiveGroupLength))
+        if verbose: print('\tVerbose len(sortedProcessiveGroupLengthList):%d' % (len(sorted_processsive_group_length_list)))
+
+    ###################################################################
+    ############### For information ends ##############################
+    ###################################################################
+
+    ###################################################################
+    ############### Plotting starts ###################################
+    ###################################################################
+    if (processive_group_length_nparray.size>0):
+        # create the directory if it does not exists
+        os.makedirs(os.path.join(outputDir, jobname, FIGURE, PROCESSIVITY), exist_ok=True)
+
+        #plot processivity figure
+        plot_processivity_figure(outputDir,
+                                 jobname,
+                                 numberofSimulations,
+                                 sorted_signature_list,
+                                 sorted_processsive_group_length_list,
+                                 maxProcessiveGroupLength,
+                                 signature_radius_df,
+                                 signature2ProcessiveGroupLength2ProcessiveGroupPropertiesDict,
+                                 verbose)
+
+        #write accompanying processivity file
+        filePath = os.path.join(outputDir, jobname, FIGURE, PROCESSIVITY, '%s_Signatures_Processivity.txt' % (jobname))
+        writeDictionaryAsADataframe(jobname, signature2ProcessiveGroupLength2ProcessiveGroupPropertiesDict, filePath)
+    ###################################################################
+    ############### Plotting ends #####################################
+    ###################################################################
+
+###################################################################
+
+
+
+###################################################################
+def plot_processivity_figure(outputDir,
+                             jobname,
+                             numberofSimulations,
+                             sorted_signature_list,
+                             sorted_processsive_group_length_list,
+                             maxProcessiveGroupLength,
+                             signature_radius_df,
+                             signature2ProcessiveGroupLength2ProcessiveGroupPropertiesDict,
+                             verbose):
 
     index = None
     if ((len(sorted_processsive_group_length_list) > 0) and (maxProcessiveGroupLength > 0)):
@@ -323,210 +375,169 @@ def plotRelationshipBetweenSignaturesandProcessiveGroupLengthsUsingDataframes(ou
         index = sorted_processsive_group_length_list.index(maxProcessiveGroupLength)
         if verbose: print('\tVerbose sortedProcessiveGroupLengthList[index]:%s' % (sorted_processsive_group_length_list[index]))
         if verbose: print('\tVerbose ##########################################')
-    ###################################################################
-    ############### For information ends ##############################
-    ###################################################################
 
-
-    ###################################################################
-    ############### Plotting starts ###################################
-    ###################################################################
-
-    ####################################################
-    #Used for scatter plot
-    x = []
-    y = []
-    c = []
-    ####################################################
-
-    ####################################################
-    # create a new figure
-    # fig = plt.figure(figsize=(maxProcessiveGroupLength, len(sortedSignatureList)), dpi=300)
-
-    # fig = plt.figure(figsize=(3 * maxProcessiveGroupLength, 3 * len(sortedSignatureList)))
-    # plt.title('%s' % (jobname), y=1.1, fontsize=40, fontweight='bold')
     if verbose: print('\tVerbose maxProcessiveGroupLength:%d len(sortedSignatureList):%d ' % (maxProcessiveGroupLength, len(sorted_signature_list)))
 
-    if len(sorted_signature_list)<=2:
-        fig = plt.figure(figsize=(15, 15))
-        plt.title('%s' % (jobname), y=1.25, fontsize=40, fontweight='bold')
-    elif (maxProcessiveGroupLength>20):
-        fig = plt.figure(figsize=(2 * maxProcessiveGroupLength,2 * len(sorted_signature_list)))
-        plt.title('%s' % (jobname), y=1.1, fontsize=40, fontweight='bold')
+    if (len(sorted_signature_list)>0):
+        plot1, panel1 = plt.subplots(figsize=(20+1.5*len(sorted_processsive_group_length_list), 10+1.5*len(sorted_signature_list)))
+        plt.rc('axes', edgecolor='lightgray')
 
-    elif (len(sorted_signature_list)>maxProcessiveGroupLength):
-        fig = plt.figure(figsize=(2*maxProcessiveGroupLength, 1.5*len(sorted_signature_list)))
-        plt.title('%s' % (jobname), y=1.1, fontsize=40, fontweight='bold')
-    elif (maxProcessiveGroupLength > len(sorted_signature_list)):
-        fig = plt.figure(figsize=(3*maxProcessiveGroupLength, 3* len(sorted_signature_list)))
-        plt.title('%s' % (jobname), y=1.1, fontsize=40, fontweight='bold')
-    elif (maxProcessiveGroupLength == len(sorted_signature_list)):
-        fig = plt.figure(figsize=(2.5*maxProcessiveGroupLength, 2.5 * len(sorted_signature_list)))
-        plt.title('%s' % (jobname), y=1.15, fontsize=40, fontweight='bold')
+        #make aspect ratio square
+        panel1.set_aspect(1.0)
 
-    ax = plt.gca()
-    ax.set_aspect(1.0)  # make aspect ratio square
-    ####################################################
+        #set title
+        panel1.text(len(sorted_processsive_group_length_list)*3, len(sorted_signature_list)+2.5, jobname,  horizontalalignment='center', fontsize=60, fontweight='bold', fontname='Arial')
 
+        panel1.set_aspect(1.0)  # make aspect ratio square
 
-    #######################################################################
-    #To get rid of  UserWarning: Attempting to set identical left==right results in singular transformations; automatically expanding.
-    if (len(sorted_processsive_group_length_list)>1):
-        plt.xlim([1,index+1])
-        ax.set_xticks(np.arange(0,index+2,1))
-    else:
-        plt.xlim([0,len(sorted_processsive_group_length_list)])
-        ax.set_xticks(np.arange(0,len(sorted_processsive_group_length_list),1))
+        #To get rid of  UserWarning: Attempting to set identical left==right results in singular transformations; automatically expanding.
+        if (len(sorted_processsive_group_length_list)>1):
+            panel1.set_xlim([1,index+1])
+            panel1.set_xticks(np.arange(0,index+2,1))
+        else:
+            panel1.set_xlim([0,len(sorted_processsive_group_length_list)])
+            panel1.set_xticks(np.arange(0,len(sorted_processsive_group_length_list),1))
 
-    if (len(sorted_signature_list)>1):
-        plt.ylim([1, len(sorted_signature_list)])
-    else:
-        plt.ylim([0, len(sorted_signature_list)])
-    #######################################################################
+        if (len(sorted_signature_list)>1):
+            panel1.set_ylim([1, len(sorted_signature_list)])
+        else:
+            panel1.set_ylim([0, len(sorted_signature_list)])
 
-    ax.set_yticks(np.arange(0, len(sorted_signature_list) + 1, 1))
+        panel1.set_yticks(np.arange(0, len(sorted_signature_list) + 1, 1))
+        #######################################################################
 
-    cmap = cm.get_cmap('YlOrRd')  # Looks better good
-    # cmap = cm.get_cmap('seismic')  # not good
-
-    #Very important: You have to normalize
-    # norm = Normalize(min_minus_log10_qvalue, max_minus_log10_qvalue)
-    # norm = Normalize(2, 50)
-    norm = Normalize(2, 20)
-
-    #######################################################################################
-    ######  simulation2Signature2ProcessiveGroupLength2PropertiesDict is None ends ########
-    #######################################################################################
-
-    ##########################################################################################
-    if (numberofSimulations>0):
-        ##########################################################################################
-        #Plot the circles with color
-        for sigIndex, signature in enumerate(sorted_signature_list):
-            for lengthIndex, processiveGroupLength in enumerate(sorted_processsive_group_length_list):
-                if (signature_radius_df[(signature_radius_df['Signature'] == signature) & (signature_radius_df['Processsive_Group_Length'] == processiveGroupLength)]['Radius'].values > 0):
-                    radius = signature_radius_df[(signature_radius_df['Signature'] == signature) & (signature_radius_df['Processsive_Group_Length'] == processiveGroupLength)]['Radius'].values[0]
-                    color=None
-                    if 'minus_log10_qvalue' in signature2ProcessiveGroupLength2ProcessiveGroupPropertiesDict[signature][processiveGroupLength]:
-                        color=signature2ProcessiveGroupLength2ProcessiveGroupPropertiesDict[signature][processiveGroupLength]['minus_log10_qvalue']
-
-                    if ((radius is not None) and (radius>0) and color):
-                        #Very important: You have to norm
-                        circle = plt.Circle((lengthIndex + 0.5, sigIndex + 0.5), radius, color=cmap(norm(color)), fill=True)
-                        ax.add_artist(circle)
-    else:
-    #There is  no simulation data therefore no p values
-    #######################################################################################
-    ######  simulation2Signature2ProcessiveGroupLength2PropertiesDict is None starts ######
-    #######################################################################################
+        #######################################################################
+        cmap = cm.get_cmap('YlOrRd')  # Looks better good
+        v_min = 2
+        v_max = 20
+        #Very important: You have to normalize
+        norm = mpl.colors.Normalize(vmin=v_min, vmax=v_max)
+        #######################################################################
 
         ##########################################################################################
-        #Plot the circles without color
-        for sigIndex, signature in enumerate(sorted_signature_list):
+        if (numberofSimulations>0):
+            #Plot the circles with color
+            for sigIndex, signature in enumerate(sorted_signature_list):
+                for lengthIndex, processiveGroupLength in enumerate(sorted_processsive_group_length_list):
+                    if (signature_radius_df[(signature_radius_df['Signature'] == signature) & (signature_radius_df['Processsive_Group_Length'] == processiveGroupLength)]['Radius'].values > 0):
+                        radius = signature_radius_df[(signature_radius_df['Signature'] == signature) & (signature_radius_df['Processsive_Group_Length'] == processiveGroupLength)]['Radius'].values[0]
+                        color=None
+                        if 'minus_log10_qvalue' in signature2ProcessiveGroupLength2ProcessiveGroupPropertiesDict[signature][processiveGroupLength]:
+                            color=signature2ProcessiveGroupLength2ProcessiveGroupPropertiesDict[signature][processiveGroupLength]['minus_log10_qvalue']
+
+                        if ((radius is not None) and (radius>0) and color):
+                            #Very important: You have to norm
+                            circle = plt.Circle((lengthIndex + 0.5, sigIndex + 0.5), radius, color=cmap(norm(color)), fill=True)
+                            panel1.add_patch(circle)
+
+        else:
+            #There is  no simulation data therefore no p values
+            #Plot the circles without color
+            for sigIndex, signature in enumerate(sorted_signature_list):
+                for lengthIndex, processiveGroupLength in enumerate(sorted_processsive_group_length_list):
+                    if (signature_radius_df[(signature_radius_df['Signature'] == signature) & (signature_radius_df['Processsive_Group_Length'] == processiveGroupLength)]['Radius'].values > 0):
+                        radius = signature_radius_df[(signature_radius_df['Signature'] == signature) & (signature_radius_df['Processsive_Group_Length'] == processiveGroupLength)]['Radius'].values[0]
+                        circle = plt.Circle((lengthIndex + 0.5, sigIndex + 0.5),radius,color="g", fill=True)
+                        panel1.add_patch(circle)
+        ##########################################################################################
+
+        panel1.set_facecolor('white')
+        #When there are subplots, this is needed.
+        panel1.grid(color='black')
+
+        panel1.grid(color='black')
+
+        for edge, spine in panel1.spines.items():
+            spine.set_visible(True)
+            spine.set_color('black')
+
+        xlabels=None
+        if (index is not None):
+            xlabels = sorted_processsive_group_length_list[0:index+1]
+        ylabels = sorted_signature_list
+        ##########################################################################################
+
+        ################### Put the color bar if there are simulations starts ###################
+        if (numberofSimulations>0):
+
+            #########################################################################################
+            #Vertical Colorbar
+            #Used for scatter plot
+            x = []
+            y = []
+            c = []
+
             for lengthIndex, processiveGroupLength in enumerate(sorted_processsive_group_length_list):
-                if (signature_radius_df[(signature_radius_df['Signature'] == signature) & (signature_radius_df['Processsive_Group_Length'] == processiveGroupLength)]['Radius'].values > 0):
-                    radius = signature_radius_df[(signature_radius_df['Signature'] == signature) & (signature_radius_df['Processsive_Group_Length'] == processiveGroupLength)]['Radius'].values[0]
-                    circle = plt.Circle((lengthIndex + 0.5, sigIndex + 0.5),radius,color="g", fill=True)
-                    ax.add_artist(circle)
-    ##########################################################################################
+                x.append(lengthIndex)
+                y.append(lengthIndex)
+                c.append(0.5)
 
+            #This code defines the ticks on the color bar
+            # plot the scatter plot
+            sc = plt.scatter(x, y, s=0, c=c, cmap=cmap, vmin=v_min, vmax=v_max, edgecolors='black')
+            cb = plt.colorbar(sc)  # this works because of the scatter
+            # cb.set_label("-log10 (q-value)", horizontalalignment='right', rotation=0, labelpad=150, fontsize=50)
 
-    ##########################################################################################
-    for lengthIndex, processiveGroupLength in enumerate(sorted_processsive_group_length_list):
-        x.append(lengthIndex)
-        y.append(lengthIndex)
-        c.append(0.5)
+            ax = cb.ax
+            ax.text(3.5, 0.5, '-log10\n (q-value)',fontsize=50)
+            #########################################################################################
 
-    #This code defines the ticks on the color bar
-    # plot the scatter plot
-    # sc = plt.scatter(x, y, s=0, c=c, cmap=cmap, vmin=min_minus_log10_qvalue, vmax=max_minus_log10_qvalue, edgecolors='black')
-    # sc = plt.scatter(x, y, s=0, c=c, cmap=cmap, vmin=2, vmax=50, edgecolors='black')
-    sc = plt.scatter(x, y, s=0, c=c, cmap=cmap, vmin=2, vmax=20, edgecolors='black')
+            ##########################################################################################
+            #common for horizontal colorbar and vertical colorbar
+            cbax = cb.ax
+            cbax.tick_params(labelsize=40)
+            text_x = cbax.xaxis.label
+            text_y = cbax.yaxis.label
+            font = mpl.font_manager.FontProperties(size=40)
+            text_x.set_font_properties(font)
+            text_y.set_font_properties(font)
+            ##########################################################################################
 
-    ax.set_facecolor('white')
-    plt.grid(color='black')
+        ################### Put the color bar if there are simulations ends #####################
 
-    for edge, spine in ax.spines.items():
-        spine.set_visible(True)
-        spine.set_color('black')
+        ##################################################################################
+        # CODE GOES HERE TO CENTER X-AXIS LABELS...
+        panel1.set_xticklabels([])
+        mticks = panel1.get_xticks()
+        panel1.set_xticks((mticks[:-1] + mticks[1:]) / 2, minor=True)
+        panel1.tick_params(axis='x', which='minor', length=0,labelsize=50)
 
-    xlabels=None
-    if (index is not None):
-        xlabels = sorted_processsive_group_length_list[0:index+1]
-    ylabels = sorted_signature_list
-    ##########################################################################################
+        if xlabels is not None:
+            panel1.set_xticklabels(xlabels, minor=True)
 
-    # We can ploy color bar in a separate figure
-    # plot_color_bar(outputDir, jobname,norm)
+        panel1.xaxis.set_ticks_position('top')
 
-    ################### Put the color bar if there are simulations starts ###################
-    if (numberofSimulations>0):
-        cb = plt.colorbar(sc)  # this works because of the scatter
-        cb.ax.set_xticklabels(cb.ax.get_xticklabels(), fontsize=30)
-        cb.ax.set_yticklabels(cb.ax.get_yticklabels(), fontsize=30)
+        plt.tick_params(
+            axis='x',  # changes apply to the x-axis
+            which='major',  # both major and minor ticks are affected
+            bottom=False,  # ticks along the bottom edge are off
+            top=False)  # labels along the bottom edge are off
+        ##################################################################################
 
-        font = mpl.font_manager.FontProperties(size=30)
-        cbax = cb.ax
-        text_x = cbax.xaxis.label
-        text_y = cbax.yaxis.label
-        text_x.set_font_properties(font)
-        text_y.set_font_properties(font)
+        ##################################################################################
+        # CODE GOES HERE TO CENTER Y-AXIS LABELS...
+        panel1.set_yticklabels([])
+        mticks = panel1.get_yticks()
+        panel1.set_yticks((mticks[:-1] + mticks[1:]) / 2, minor=True)
+        panel1.tick_params(axis='y', which='minor', length=0,labelsize=50)
+        panel1.set_yticklabels(ylabels, minor=True) # fontsize
 
-        # cb.set_label("-log10\n  (q-value)", horizontalalignment='right', rotation=0, labelpad=150)
-        cb.set_label("-log10\n  (q-value)", horizontalalignment='right', rotation=0, labelpad=150, fontsize=30)
-    ################### Put the color bar if there are simulations ends #####################
+        plt.tick_params(
+            axis='y',  # changes apply to the x-axis
+            which='major',  # both major and minor ticks are affected
+            left=False)  # labels along the bottom edge are off
+        ##################################################################################
 
-    ##################################################################################
-    # CODE GOES HERE TO CENTER X-AXIS LABELS...
-    ax.set_xticklabels([])
-    mticks = ax.get_xticks()
+        ##################################################################################
+        filename = '%s_Processivity.png' %(jobname)
+        figFile = os.path.join(outputDir, jobname, FIGURE, PROCESSIVITY, filename)
+        plot1.savefig(figFile)
+        plot1.tight_layout()
 
-    ax.set_xticks((mticks[:-1] + mticks[1:]) / 2, minor=True)
-    ax.tick_params(axis='x', which='minor', length=0,labelsize=40)
+        plt.cla()
+        plt.close(plot1)
+        ##################################################################################
 
-    if xlabels is not None:
-        ax.set_xticklabels(xlabels, minor=True)
-
-    ax.xaxis.set_ticks_position('top')
-
-    plt.tick_params(
-        axis='x',  # changes apply to the x-axis
-        which='major',  # both major and minor ticks are affected
-        bottom=False,  # ticks along the bottom edge are off
-        top=False)  # labels along the bottom edge are off
-    ##################################################################################
-
-    ##################################################################################
-    # CODE GOES HERE TO CENTER Y-AXIS LABELS...
-    ax.set_yticklabels([])
-    mticks = ax.get_yticks()
-    ax.set_yticks((mticks[:-1] + mticks[1:]) / 2, minor=True)
-    ax.tick_params(axis='y', which='minor', length=0,labelsize=40)
-    ax.set_yticklabels(ylabels, minor=True) # fontsize
-
-    plt.tick_params(
-        axis='y',  # changes apply to the x-axis
-        which='major',  # both major and minor ticks are affected
-        left=False)  # labels along the bottom edge are off
-    ##################################################################################
-
-    ##################################################################################
-    #create the directory if it does not exists
-    os.makedirs(os.path.join(outputDir, jobname, FIGURE, ALL, PROCESSIVITY), exist_ok=True)
-    filename = '%s_Processivity.png' %(jobname)
-
-    figFile = os.path.join(outputDir, jobname, FIGURE, ALL, PROCESSIVITY, filename)
-    fig.savefig(figFile)
-    plt.cla()
-    plt.close(fig)
-    ##################################################################################
-
-    ###################################################################
-    ############### Plotting ends #####################################
-    ###################################################################
-
-    filePath=os.path.join(outputDir, jobname, FIGURE, ALL, PROCESSIVITY,'%s_Signatures_Processivity.txt' %(jobname))
-    writeDictionaryAsADataframe(jobname,signature2ProcessiveGroupLength2ProcessiveGroupPropertiesDict, filePath)
 ###################################################################
 
 
@@ -553,30 +564,9 @@ def writeDictionaryAsADataframe(jobname,signature2ProcessiveGroupLength2Processi
 ###################################################################
 def processivityFigures(outputDir,jobname,numberofSimulations,verbose):
 
-    jobnamePath = os.path.join(outputDir,jobname,FIGURE,ALL,PROCESSIVITY)
+    jobnamePath = os.path.join(outputDir,jobname,FIGURE,PROCESSIVITY)
     if verbose: print('\tVerbose Topography.py jobnamePath:%s ' %jobnamePath)
 
-    simulation2Signature2ProcessiveGroupLength2PropertiesDict = None
-
-    ############################################################
-    if (numberofSimulations > 0):
-        simulation2Signature2ProcessiveGroupLength2PropertiesDict = readSimulationBasedDictionaries(outputDir,jobname,numberofSimulations)
-    ############################################################
-
-    ############################################################
-    filename = 'Sim0_Signature2ProcessiveGroupLength2PropertiesDict.txt'
-    originalSignature2ProcessiveGroupLength2PropertiesDictFilePath = os.path.join(outputDir,jobname,DATA,PROCESSIVITY,filename)
-    originalSignature2ProcessiveGroupLength2PropertiesDict = readDictionary(originalSignature2ProcessiveGroupLength2PropertiesDictFilePath)
-    ############################################################
-
-    ############################################################
-    if (numberofSimulations > 0):
-        if verbose: print('\tVerbose Which simulations are available?: simulation2Signature2ProcessiveGroupLength2PropertiesDict.keys()')
-        if verbose: print('\tVerbose %s' %(simulation2Signature2ProcessiveGroupLength2PropertiesDict.keys()))
-        if verbose: print('\tVerbose Number of simulations: len(simulation2Signature2ProcessiveGroupLength2PropertiesDict.keys())')
-        if verbose: print('\tVerbose %d' %(len(simulation2Signature2ProcessiveGroupLength2PropertiesDict.keys())))
-    ############################################################
-
     ############################################################
     processivity_table_file_list=[]
     processivity_df_list=[]
@@ -592,7 +582,13 @@ def processivityFigures(outputDir,jobname,numberofSimulations,verbose):
         #Signature       Processsive_Group_Length        Number_of_Processive_Groups     Median_of_Number_of_Processive_Groups_in_MB
         processivity_df=pd.read_csv(processivity_table_file, header=0, sep='\t')
         processivity_df['Simulation_Number']=simNum
-        processivity_df=processivity_df[['Simulation_Number', 'Signature', 'Processsive_Group_Length', 'Number_of_Processive_Groups', 'Median_of_Number_of_Processive_Groups_in_MB']]
+        processivity_df=processivity_df[['Simulation_Number',
+                                         'Signature',
+                                         'Processsive_Group_Length',
+                                         'Number_of_Processive_Groups',
+                                         'Median_Distance_Between_Last_First_Mutations',
+                                         'Median_Distance_Between_Consecutive_Mutations',
+                                         'Median_Number_of_Mutations_Within_1MB']]
         processivity_df_list.append(processivity_df)
 
     # Vertically combine dfs
